=======
History
=======

0.3.0 (2023-03-15)
-------------------
* Included UKF tractography
* Included regularized tractography

0.2.0 (2021-09-17)
-------------------
* Included the missing steps of the whole tracking pipeline.

0.1.2 (2019-02-26)
-------------------

* 'mtdeconv': If response is available, files needed for the computation of the response are not loaded.

0.1.1 (2019-02-06)
-------------------

* First release on PyPI.

0.1.0 (2019-02-06)
------------------

* Making repository public on Github
